@@ -27,7 +27,6 @@ class Image(Media):
             self.height = self.data.size[1]
             self.width = self.data.size[0]
             self.format = self.data.format
-            self.data.close()
         elif isinstance(data, PIL.Image.Image):
             self.data = data
             # data가 PIL.Image 객체인 경우 7자리의 random id값을 생성한후 {random_id}.{file_format}으로 저장
@@ -69,7 +68,8 @@ class Image(Media):
         path = self.get_path(key_name)
         logger.debug(f"file upload[image] : local_path=[{self.local_path}], root_path=[{root_path}], path=[{path}]")
         interface.upload_file(upload_type="RUN", local_path=self.local_path, root_path=root_path, path=path,
-                              run_id=run.run_id, artifact_id=0, last_file_yn="Y", teamName="", expName="",
+                              run_id=run.run_id, artifact_id=0, last_file_yn="Y", teamName=run.team_name, expName=run.exp_name,
+                              run_name=run.run_name,
                               artifact_name="", artifact_type="", artifact_digest="", entry_digest=digest,
                               entry_list=[], file_index=0)
 
